==> dpsrc.2008_10_02.tar.gz: gd_src.f <==
      SUBROUTINE GDDRAW(IX1,IY1,IX2,IY2,JCOL,JPATT)
      RETURN
      END
      SUBROUTINE GDPOIN(IX,IY,JCOL)
      INTEGER IX(*), IY(*), JCOL
      RETURN
      END
      SUBROUTINE GDCIRC(IX,IY,IRAD,IFILL,JCOL)
      RETURN
      END
      SUBROUTINE GDEND(INAME)
      INTEGER INAME(*)
      RETURN
      END
      SUBROUTINE GDRGFL(IX,IY,NPTS,JCOL)
      INTEGER IX(*), IY(*)
      RETURN
      END
      SUBROUTINE GDSECO(INDEX)
      RETURN
      END
      SUBROUTINE GDSEC2(IRED,IGREEN,IBLUE)
      RETURN
      END
      SUBROUTINE GDSEPA(INDEX)
      RETURN
      END
      SUBROUTINE GDTXTV(IFONT,ISTRNG,IFONTZ,IXPOS,IYPOS,IJUSTH,IJUSTV,
     1                  ICOL,IHEIGH,IERROR)
      INTEGER ISTRNG(*)
      INTEGER IFONT(*)
      RETURN
      END
      SUBROUTINE GDTXTH(IFONT,ISTRNG,IFONTZ,IXPOS,IYPOS,IJUSTH,IJUSTV,
     1                  ICOL,IHEIGH,IERROR)
      INTEGER ISTRNG(*)
      INTEGER IFONT(*)
      RETURN
      END
      SUBROUTINE GDINIT(ITYPE)
      INTEGER ITYPE
      WRITE(*,*) ' GD DRIVERS HAVE NOT BEEN INSTALLED AT YOUR SITE'
      WRITE(*,*) ' CONTACT YOUR LOCAL SITE COORDINATER FOR '
      WRITE(*,*) ' MORE INFORMATION'
      RETURN
      END
      SUBROUTINE GDERAS(IX,IY,IBACK,ITYPE,IFILE)
      INTEGER IX(*)
      INTEGER IY(*)
      INTEGER IFILE(*)
      RETURN
      END
      SUBROUTINE GDLOAD(ITYPE,IXPIXE,IYPIXE,IFILE,IERROR)
      INTEGER IFILE(*)
      RETURN
      END
      SUBROUTINE GDPIXE(IXPOS,IYPOS,IRED,IGREEN,IBLUE)
      RETURN
      END
      SUBROUTINE GDUNLO()
      RETURN
      END

==> dpsrc_2013_12_20.tar.gz: gd_src.f <==
      SUBROUTINE GDDRAW(IX1,IY1,IX2,IY2,JCOL,JPATT)
      RETURN
      END
      SUBROUTINE GDPOIN(IX,IY,JCOL)
      INTEGER IX, IY, JCOL
      RETURN
      END
      SUBROUTINE GDCIRC(IX,IY,IRAD,IFILL,JCOL)
      RETURN
      END
      SUBROUTINE GDEND(INAME)
      INTEGER INAME(*)
      RETURN
      END
      SUBROUTINE GDRGFL(IX,IY,NPTS,JCOL)
      INTEGER IX(*), IY(*)
      RETURN
      END
      SUBROUTINE GDSECO(INDEX)
      RETURN
      END
      SUBROUTINE GDSEC2(IRED,IGREEN,IBLUE,IRETCO)
      RETURN
      END
      SUBROUTINE GDSEPA(INDEX)
      RETURN
      END
      SUBROUTINE GDTXTV(IFONT,ISTRNG,IFONTZ,IXPOS,IYPOS,IJUSTH,IJUSTV,
     1                  ICOL,IHEIGH,IERROR)
      INTEGER ISTRNG(*)
      INTEGER IFONT(*)
      RETURN
      END
      SUBROUTINE GDTXTH(IFONT,ISTRNG,IFONTZ,IXPOS,IYPOS,IJUSTH,IJUSTV,
     1                  ICOL,IHEIGH,IERROR)
      INTEGER ISTRNG(*)
      INTEGER IFONT(*)
      RETURN
      END
      SUBROUTINE GDINIT(ITYPE)
      INTEGER ITYPE
      WRITE(*,*) ' GD DRIVERS HAVE NOT BEEN INSTALLED AT YOUR SITE'
      WRITE(*,*) ' CONTACT YOUR LOCAL SITE COORDINATER FOR '
      WRITE(*,*) ' MORE INFORMATION'
      RETURN
      END
      SUBROUTINE GDERAS(IX,IY,IBACK,ITYPE,IFILE)
      INTEGER IX
      INTEGER IY
      INTEGER IFILE(*)
      RETURN
      END
      SUBROUTINE GDLOAD(ITYPE,IXPIXE,IYPIXE,IFILE,IERROR)
      INTEGER IFILE(*)
      RETURN
      END
      SUBROUTINE GDPIXE(IXPOS,IYPOS,IRED,IGREEN,IBLUE)
      RETURN
      END
      SUBROUTINE GDUNLO()
      RETURN
      END
